@@ -1,28 +1,34 @@
+# (C) Copyright 2020 ECMWF.
+#
+# This software is licensed under the terms of the Apache Licence Version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#
+import os
+
 import climetlab as cml
 import climetlab.utils
 import climetlab.utils.conventions
 import pandas
+import yaml
 
-from . import ALIAS_FCTYPE, ALIAS_ORIGIN, DATA_VERSION, PATTERN_GRIB, PATTERN_NCDF
-
-ALIAS_DATASETNAMES = {
-    "hindcast-input": "training-input",
-    "forecast-input": "test-input",
-    "hindcast-input-dev": "training-input-dev",
-    "forecast-input-dev": "test-input-dev",
-    "hindcast-like-observations": "training-output-reference",
-    "forecast-like-observations": "test-output-reference",
-    "forecast-benchmark": "test-output-benchmark",
-}
+from . import (
+    ALIAS_DATASETNAMES,
+    ALIAS_FCTYPE,
+    ALIAS_ORIGIN,
+    DATA_VERSION,
+    PATTERN_GRIB,
+    PATTERN_NCDF,
+)
 
 
 class Info:
     def __init__(self, dataset):
-        import os
-
-        import yaml
-
-        #        dataset = ALIAS_DATASETNAMES.get(dataset, dataset)
+        if "_" in dataset and dataset not in ALIAS_DATASETNAMES.keys():
+            raise ValueError(f'Cannot find {dataset}. Did you mean {dataset.replace("_", "-")} maybe ?')
+        dataset = ALIAS_DATASETNAMES[dataset]
         self.dataset = dataset
 
         filename = self.dataset.replace("-", "_") + ".yaml"
@@ -33,6 +39,15 @@ class Info:
                 if "alldates" in v:
                     v["alldates"] = pandas.date_range(**v["alldates"])
 
+        self.fctype = self._guess_fctype()
+
+    def _guess_fctype(self):
+        keys = self.config.keys()
+        fctypes = [k.split("-")[-1] for k in keys]
+        fctypes = list(set(fctypes))  # make unique
+        assert len(fctypes) == 1
+        return fctypes[0]
+
     def _get_cf_name(self, param):
         return cml.utils.conventions.normalise_string(param, convention="cf")
 
@@ -81,9 +96,13 @@ class Info:
             date=date,
         )
 
-    def _get_config(self, key, origin, fctype, date=None, param=None):
+    def _get_config(self, key, origin, fctype=None, date=None, param=None):
         origin = ALIAS_ORIGIN[origin]
+
+        if fctype is None:
+            fctype = self.fctype
         fctype = ALIAS_FCTYPE[fctype]
+
         origin_fctype = f"{origin}-{fctype}"
 
         import pandas as pd
@@ -102,3 +121,8 @@ class Info:
         if param is None:
             return self.config[origin_fctype][key]
         return self.config[origin_fctype][param][key]
+
+    def get_param_list(self, origin, fctype=None):
+        lst = self._get_config("param", origin, fctype)
+        lst = [self._get_cf_name(p) for p in lst]
+        return lst
